pub struct ResponseReceiver { /* private fields */ }Implementations
Sourceimpl ResponseReceiver
impl ResponseReceiver
pub async fn recv(&mut self) -> Option<MessageResponse>
Sourcepub async fn recv_initial(
&mut self,
) -> Result<MessageResponse, ReceiveOkResponseError>
pub async fn recv_initial( &mut self, ) -> Result<MessageResponse, ReceiveOkResponseError>
Receive one message within the connection’s initial timeout.
Sourcepub async fn get_response(
&mut self,
) -> Result<Result<OkResponse, ErrorResponse>, ReceiveOkResponseError>
pub async fn get_response( &mut self, ) -> Result<Result<OkResponse, ErrorResponse>, ReceiveOkResponseError>
Get the OK or error response from the machine, ignoring NEXT messages. Uses connection’s default timeouts: initial_timeout for first response, next_to_ok_timeout after NEXT.
Sourcepub async fn get_response_with_timeout(
&mut self,
timeout_duration: Duration,
) -> Result<Result<OkResponse, ErrorResponse>, ReceiveOkResponseError>
pub async fn get_response_with_timeout( &mut self, timeout_duration: Duration, ) -> Result<Result<OkResponse, ErrorResponse>, ReceiveOkResponseError>
Get the OK or error response with a single timeout, ignoring connection defaults. Times out if OK/Error is not received within the specified timeout.
Sourcepub async fn get_response_with_next_and_ok_timeout(
&mut self,
initial: Duration,
next_to_ok: Duration,
) -> Result<Result<OkResponse, ErrorResponse>, ReceiveOkResponseError>
pub async fn get_response_with_next_and_ok_timeout( &mut self, initial: Duration, next_to_ok: Duration, ) -> Result<Result<OkResponse, ErrorResponse>, ReceiveOkResponseError>
Get the OK or error response with custom timeouts for initial wait and post-NEXT wait.